@@ -11,11 +11,14 @@ from .scripts import praatscripts
 
 
 class PraatLoader:
-    def __init__(self,praatpath):
+    def __init__(self,praatpath,debug=False):
+        self.debug=debug
         self.scripts = praatscripts
         self.script_dir = os.path.join(os.path.dirname(praatpath),'praatScripts')
         self.praat = praatpath
         self.init_scripts()
+        if debug:
+            self.initlog()
 
     def init_scripts(self):
         if not os.path.isdir(self.script_dir):
@@ -26,6 +29,14 @@ class PraatLoader:
             with open(os.path.join(self.script_dir,s),'w') as f:
                 f.write(self.scripts[s])
 
+    def initlog(self):
+        with open(self.script_dir,'w') as f:
+            f.write("begin")
+
+    def updatelog(self,line):
+        with open(self.script_dir,'a') as f:
+            f.write(line+"\n")
+
     def get_formants(self,filename,begin,end,nformants,ceiling):
         output = self.run_script("formants-all.praat",[filename,begin,end,nformants,ceiling])
         output = self.read_praat_out(output)
@@ -43,9 +54,16 @@ class PraatLoader:
         out = self.run_script('waveformPic.praat',[filename,numbounds,boundaries])
 
     def run_script(self,name,args):
+        if debug:
+            updatelog('%s' % name)
         com = [self.praat, os.path.join(self.script_dir,name)] + map(str,args)
+        if debug:
+            updatelog('%s' % str(com))
         p = subprocess.Popen(com,stdout=subprocess.PIPE,stderr=subprocess.PIPE,stdin=subprocess.PIPE)
         stdout, stderr = p.communicate()
+        if debug:
+            updatelog('stdout: %s' % str(stdout))
+            updatelog('stderr: %s' % str(stderr))
         if stderr != '':
             print stderr
         return stdout
